# needed packages

library(ggplot2)
library(unmarked)
library(AICcmodavg)
library(gridExtra)
library(grid)

# custom function, that creates the custom theme for these graphs, named from my PI David Krementz
theme_krementz <- function(){
  theme(axis.text.x = element_text(size=18,color="black"),
        axis.text.y = element_text(size=18,color="black"),
        axis.title.y=element_text(size=20),
        plot.background = element_blank(),
        panel.border=element_blank(),
        panel.grid.major= element_line(colour=NA), 
        panel.grid.minor=element_line(colour=NA),
        title=element_text(size=20),
        panel.background = element_rect(fill = "white"),
        axis.line=element_line(colour="black"),
        strip.background=element_rect(fill="white", color="black"),
        strip.text=element_text(size=15))
}

# needed data
load("vegDONE.rda") # also see vegDONE.csv
load("./poisson_models.Rdata") # the models from gdistsamp_mdoel_run.R

cov <- vegDONE


# creating a data frame where water depth varies, but other variables are held cosntant
new_dat <- data.frame(scale_averagewater=c(seq(min(cov$scale_averagewater), max(cov$scale_averagewater), length.out=50)), scale_int=mean(cov$scale_int), scale_short=mean(cov$scale_short), year=factor(2013, levels=c(2012,2013,2014,2015)), averagewater=c(seq(min(cov$averagewater),max(cov$averagewater),length.out=50)))

# creating the water squared variable
new_dat$scale_averagewater2 <- new_dat$scale_averagewater^2

# predicting sora density from the global mode (top model) given our new data frame
pred <- predict(density.modelsP$global, newdat=new_dat, type="lambda")

# binding together the new data frame and our predictions
water.pre <- cbind(new_dat, pred)


(w15 <- ggplot(data=water.pre)+
  geom_ribbon(aes(x=averagewater, y=Predicted, ymin=lower, ymax=upper), fill="grey")+
  geom_line(aes(x=averagewater, y=Predicted))+
  ylab("Sora Density \n(Sora/Hectare)")+
  xlab("Average Water Depth (cm)")+
  ylim(0,30)+
  theme_krementz())


# creating a data frame where non-persistent moist soil vegetation varies, but other variables are held cosntant
new_dat <- data.frame(scale_short=c(seq(min(cov$scale_short), max(cov$scale_short), length.out=50)), scale_int=mean(cov$scale_int), scale_averagewater=mean(cov$scale_averagewater), year=factor(2013, levels=c(2012,2013,2014,2015)), short=c(seq(min(cov$short),max(cov$short),length.out=50)))

# creating the water squared variable
new_dat$scale_averagewater2 <- new_dat$scale_averagewater^2

# predicting sora density from the global mode (top model) given our new data frame
pred <- predict(density.modelsP$global, newdat=new_dat, type="lambda")

# binding together the new data frame and our predictions
water.pre <- cbind(new_dat, pred)

(s15 <- ggplot(data=water.pre)+
  geom_ribbon(aes(x=short, y=Predicted, ymin=lower, ymax=upper), fill="grey")+
  geom_line(aes(x=short, y=Predicted))+
  ylab("Sora Density \n(Sora/Hectare)")+
  xlab("Non-persistent Moist Soil Vegetation \nPercent Cover")+
  ylim(0,45)+
  theme_krementz())


jpeg(file="~/manuscripts/Dissertation_Chapter_2_Habitat_Sora/chapter2_figure2.jpg", height=25, width=20, unit="cm", res=1200)
grid.arrange(w15,s15,ncol=1)
dev.off()