library(ResourceSelection)
library(ggplot2)
library(gridExtra)
library(tidyr)
library(dplyr)

load("allveg.rda") # or allveg.csv

allveg <- allveg[allveg$bv!="day",] # removing the veg points where the bird was detected during the day
allveg <- allveg[allveg$averagewater<=900,] # removing veg points where water is under 900. values entered over 900 indicated that the water was too deep to be measured
allveg <- allveg[allveg$year!=2012,] # removing 2012 data since it was not collected under a available vs used framework
allveg <- allveg[!is.na(allveg$bv),] # removing points where the status was not recorded

allveg$STATUS <- NA # removing points where the status was not recorded

allveg[allveg$bv=="b",]$STATUS <- 1 # used points are 1s
allveg[allveg$bv=="v",]$STATUS <- 0 # available points are 0s

allveg$s_water <- scale(allveg$averagewater)
allveg$s_short <- scale(allveg$short)
allveg$s_pe <- scale(allveg$pe)
allveg$s_int <- scale(allveg$int)
allveg$year <- as.factor(allveg$year)
allveg$round <- as.factor(allveg$round) # round = visit

allveg1 <- allveg[allveg$round==1,] # visit 1 subset
allveg11 <- allveg1[allveg1$STATUS==1,]
allveg10 <- allveg1[allveg1$STATUS==0,]
allveg10 <- allveg10[sample(nrow(allveg10), 197),] # subsetting so that used and available have the same sample size
allveg1 <- rbind(allveg10, allveg11) # puts them back in the same dataframe

allveg2 <- allveg[allveg$round==2,] # visit 2 subset
allveg21 <- allveg2[allveg2$STATUS==1,]
allveg20 <- allveg2[allveg2$STATUS==0,]
allveg20 <- allveg20[sample(nrow(allveg20), 376),] # subsetting so that used and available have the same sample size
allveg2 <- rbind(allveg20, allveg21) # puts them back in the same dataframe

allveg3 <- allveg[allveg$round==3,] # visit 3 subset
allveg31 <- allveg3[allveg3$STATUS==1,]
allveg30 <- allveg3[allveg3$STATUS==0,]
allveg30 <- allveg30[sample(nrow(allveg30),553),] # subsetting so that used and available have the same sample size
allveg3 <- rbind(allveg30, allveg31) # puts them back in the same dataframe

allveg4 <- allveg[allveg$round==4,] # visit 4 subset
allveg41 <- allveg4[allveg4$STATUS==1,]
allveg40 <- allveg4[allveg4$STATUS==0,]
allveg40 <- allveg40[sample(nrow(allveg40),333),] # subsetting so that used and available have the same sample size
allveg4 <- rbind(allveg40, allveg41) # puts them back in the same dataframe


theme_krementz <- function(){
  theme(axis.text.x = element_text(size=18,color="black"),
        axis.text.y = element_text(size=18,color="black"),
        axis.title.y=element_text(size=20),
        plot.background = element_blank(),
        panel.border=element_blank(),
        panel.grid.major= element_line(colour=NA), 
        panel.grid.minor=element_line(colour=NA),
        title=element_text(size=20),
        panel.background = element_rect(fill = "white"),
        axis.line=element_line(colour="black"),
        strip.background=element_rect(fill="white", color="black"),
        strip.text=element_text(size=15))
}


allv1 <- allveg1[,c("STATUS","int","short","averagewater")]

colnames(allv1) <- c("STATUS","interspersion","non-persistent \nmoist soil","average \nwater depth")

allv1$STAT <- NA

allv1[allv1$STATUS==0,]$STAT <- "Available"
allv1[allv1$STATUS==1,]$STAT <- "Used"

gallv1 <- allv1 %>% gather("variable","value", -STAT,-STATUS)

gallv1$lab <- "*"


v1 <- ggplot(data=gallv1[gallv1$variable!="average \nwater depth",])+geom_boxplot(aes(x=factor(variable), y=value, fill=factor(STAT)))+
  theme_krementz()+
  scale_fill_manual(" ", values=c("#CCCCCC","#666666"))+
  theme(legend.position="top", legend.direction="horizontal", legend.text=element_text(size=20), axis.title=element_text(size=18), axis.text=element_text(size=18))+xlab("")+ylab("Percent \nSurvey 1")+geom_text(aes(x=variable, y=90, label=lab), size=10)

w1 <- ggplot(data=gallv1[gallv1$variable=="average \nwater depth",])+geom_boxplot(aes(x=factor(variable), y=value, fill=factor(STAT)))+theme_krementz()+  scale_fill_manual(" ", values=c("#CCCCCC","#666666"))+theme(legend.position="top", legend.direction="horizontal",legend.text=element_text(size=20), axis.title=element_text(size=18), axis.text=element_text(size=18))+xlab("")+ylab("Water Depth (cm)")+geom_text(aes(x=variable, y=53.5, label=lab), size=10)+ylim(0,60)



allv2 <- allveg2[,c("STATUS","int","short","averagewater")]

colnames(allv2) <-  c("STATUS","interspersion","non-persistent \nmoist soil","average \nwater depth")

gallv2 <- allv2 %>% gather("variable","value", -STATUS)

gallv2$lab <- "*"


v2 <- ggplot(data=gallv2[gallv2$variable!="average \nwater depth",])+geom_boxplot(aes(x=factor(variable), y=value, fill=factor(STATUS)))+theme_krementz()+  scale_fill_manual(" ", values=c("#CCCCCC","#666666"))+theme(legend.position="none", legend.direction="horizontal", axis.text=element_text(size=18), axis.title=element_text(size=18))+xlab("")+ylab("Percent \nSurvey 2")+geom_text(aes(x=variable, y=90, label=lab), size=10)

w2 <- ggplot(data=gallv2[gallv2$variable=="average \nwater depth",])+geom_boxplot( aes(x=factor(variable), y=value, fill=factor(STATUS)))+theme_krementz()+  scale_fill_manual(" ", values=c("#CCCCCC","#666666"))+theme(legend.position="none", legend.direction="horizontal", axis.text=element_text(size=18), axis.title=element_text(size=18))+xlab("")+ylab("Water Depth (cm)")+geom_text(aes(x=variable, y=53.5, label=lab), size=10)

allv3 <- allveg3[,c("STATUS","int","short","averagewater")]

colnames(allv3) <-  c("STATUS","interspersion","non-persistent \nmoist soil","average \nwater depth")
gallv3 <- allv3 %>% gather("variable","value", -STATUS)

gallv3$lab <- NA

gallv3[gallv3$variable=="non-persistent \nmoist soil"|gallv3$variable=="average \nwater depth",]$lab <- "*"


v3 <- ggplot(data=gallv3[gallv3$variable!="average \nwater depth",])+geom_boxplot( aes(x=factor(variable), y=value, fill=factor(STATUS)))+theme_krementz()+  scale_fill_manual(" ", values=c("#CCCCCC","#666666"))+theme(legend.position="none", legend.direction="horizontal", axis.text=element_text(size=18), axis.title=element_text(size=18))+xlab("")+ylab("Percent \nSurvey 3")+geom_text(aes(x=variable, y=90, label=lab), size=10)

w3 <- ggplot(data=gallv3[gallv3$variable=="average \nwater depth",])+geom_boxplot( aes(x=factor(variable), y=value, fill=factor(STATUS)))+theme_krementz()+  scale_fill_manual(" ", values=c("#CCCCCC","#666666"))+theme(legend.position="none", legend.direction="horizontal", axis.text=element_text(size=18), axis.title=element_text(size=18))+xlab("")+ylab("Water Depth (cm)")+geom_text(aes(x=variable, y=53.5, label=lab), size=10)

allv4 <- allveg4[,c("STATUS","int","short","averagewater")]

colnames(allv4) <- c("STATUS","interspersion","non-persistent \nmoist soil","average \nwater depth")

gallv4 <- allv4 %>% gather("variable","value", -STATUS)

gallv4$lab <- NA

gallv4[gallv4$variable=="non-persistent \nmoist soil"|gallv4$variable=="average \nwater depth",]$lab <- "*"



v4 <- ggplot(data=gallv4[gallv4$variable!="average \nwater depth",])+geom_boxplot( aes(x=factor(variable), y=value, fill=factor(STATUS)))+theme_krementz()+  scale_fill_manual(" ", values=c("#CCCCCC","#666666"))+theme(legend.position="none", legend.direction="horizontal", axis.text=element_text(size=18), axis.title=element_text(size=18))+xlab("")+ylab("Percent \nSurvey 4")+geom_text(aes(x=variable, y=90, label=lab), size=10)

w4 <- ggplot(data=gallv4[gallv4$variable=="average \nwater depth",])+geom_boxplot( aes(x=factor(variable), y=value, fill=factor(STATUS)))+theme_krementz()+  scale_fill_manual(" ", values=c("#CCCCCC","#666666"))+theme(legend.position="none", legend.direction="horizontal", axis.text=element_text(size=18), axis.title=element_text(size=18))+xlab("")+ylab("Water Depth (cm)")+geom_text(aes(x=variable, y=53.5, label=lab), size=10)+ylim(0,60)

jpeg(file="~/manuscripts/Dissertation_Chapter_2_Habitat_Sora/chapter2_figure3.jpg", width=25, height=40, units="cm", res=1200)
grid.arrange(v1, w1, v2, w2,v3, w3,  v4, w4,ncol=2,widths=c(4,3), heights=c(3.75,3,3,3))
dev.off()